@@ -23,7 +23,7 @@
 ##' @param prop_sub_1 passed to \link[DisImpact]{di_ppg}; defaults to 0.50.
 ##' @param di_prop_index_cutoff Threshold used for determining disproportionate impact using the proportionality index; passed to \link[DisImpact]{di_prop_index}; defaults to 0.80.
 ##' @param di_80_index_cutoff Threshold used for determining disproportionate impact using the 80\% index; passed to \link[DisImpact]{di_80_index}; defaults to 0.80.
-##' @param di_80_index_reference_groups A character vector of the same length as \code{group_vars} that indicates the reference group value for each group variable in \code{group_vars} when determining disproportionate impact using the 80\% index; defaults to \code{NA} (highest performing group as reference).
+##' @param di_80_index_reference_groups A character vector of the same length as \code{group_vars} that indicates the reference group value for each group variable in \code{group_vars} when determining disproportionate impact using the 80\% index; defaults to \code{'hpg'} (highest performing group as reference).
 ##' @param check_valid_reference Check whether \code{ppg_reference_groups} and \code{di_80_index_reference_groups} contain valid values; defaults to \code{TRUE}.
 ##' @return A summarized data set (data frame) consisting of:
 ##' \itemize{
@@ -47,11 +47,25 @@
 ##' @importFrom purrr pmap
 ##' @importFrom tidyr unnest
 ##' @export
-di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenario_repeat_by_vars=NULL, exclude_scenario_df=NULL, weight_var=NULL, include_non_disagg_results=TRUE, ppg_reference_groups='overall', min_moe=0.03, use_prop_in_moe=FALSE, prop_sub_0=0.5, prop_sub_1=0.5, di_prop_index_cutoff=0.80, di_80_index_cutoff=0.80, di_80_index_reference_groups=NA, check_valid_reference=TRUE) {
+di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenario_repeat_by_vars=NULL, exclude_scenario_df=NULL, weight_var=NULL, include_non_disagg_results=TRUE, ppg_reference_groups='overall', min_moe=0.03, use_prop_in_moe=FALSE, prop_sub_0=0.5, prop_sub_1=0.5, di_prop_index_cutoff=0.80, di_80_index_cutoff=0.80, di_80_index_reference_groups='hpg', check_valid_reference=TRUE) {
   stopifnot(length(group_vars) == length(ppg_reference_groups) | length(ppg_reference_groups) == 1)
-  stopifnot(length(group_vars) == length(di_80_index_reference_groups) | is.na(di_80_index_reference_groups))
+  stopifnot(length(group_vars) == length(di_80_index_reference_groups) | length(di_80_index_reference_groups) == 1)
 
-  # Check valid group
+  # Check valid success_vars
+  for (i in seq_along(success_vars)) {
+    if (!(success_vars[i] %in% names(data))) {
+      stop(paste0("'", success_vars[i], "' specified in `success_vars` is not found in `data`."))
+    }
+  }
+
+  # Check valid group_vars
+  for (i in seq_along(group_vars)) {
+    if (!(group_vars[i] %in% names(data))) {
+      stop(paste0("'", group_vars[i], "' specified in `group_vars` is not found in `data`."))
+    }
+  }
+
+  # Check valid reference groups
   if (check_valid_reference) {
     for (i in 1:length(ppg_reference_groups)) {
       if (!(ppg_reference_groups[i] %in% c(as.character(formals(di_ppg)$reference)[-1], unique(data[[group_vars[i]]])))) {
@@ -59,7 +73,7 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
       }
     }
     for (i in 1:length(di_80_index_reference_groups)) {
-      if (!(di_80_index_reference_groups[i] %in% c(unique(data[[group_vars[i]]]))) & !is.na(di_80_index_reference_groups[i])) {
+      if (!(di_80_index_reference_groups[i] %in% c(unique(data[[group_vars[i]]]), 'hpg')) & !is.na(di_80_index_reference_groups[i])) {
         stop(paste0("'", di_80_index_reference_groups[i], "'", " is not valid for the argument `di_80_index_reference_groups` as it does not exist in the group variable `", group_vars[i], "`."))
       }
     }
@@ -76,7 +90,7 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
     } # else leave as is (overall, hpg, all but current to be used)
     if (length(di_80_index_reference_groups) > 1) {
       di_80_index_reference_groups <- c(di_80_index_reference_groups, NA) # Adding last NA for non-disaggregated results
-    } else if (length(di_80_index_reference_groups) == 1 & !is.na(di_80_index_reference_groups)) {
+    } else if (length(di_80_index_reference_groups) == 1 & !(is.na(di_80_index_reference_groups) | di_80_index_reference_groups=='hpg')) {
       di_80_index_reference_groups <- c(di_80_index_reference_groups, NA)
     } # else leave as is (overall, hpg, all but current to be used)
   }
@@ -86,14 +100,29 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
   }
   
   if (!is.null(scenario_repeat_by_vars)) {
+    # Check valid scenario_repeat_by_vars
+    for (i in seq_along(scenario_repeat_by_vars)) {
+      if (!(scenario_repeat_by_vars[i] %in% names(data))) {
+        stop(paste0("'", scenario_repeat_by_vars[i], "' specified in `scenario_repeat_by_vars` is not found in `data`."))
+      }
+    }
     if (length(unique(sapply(data[, scenario_repeat_by_vars], class))) > 1) {
       stop("All variables specified in `scenario_repeat_by_vars` should be of the same class.  Suggestion: set them all as character data.")
-    } 
+    }
+
   }
 
   if (is.null(cohort_vars)) {
     cohort_vars <- '_cohort_'
     data[[cohort_vars]] <- '- All'
+  } else {
+    # Check valid cohort_vars
+    for (i in seq_along(cohort_vars)) {
+      if (!(cohort_vars[i] %in% names(data))) {
+        stop(paste0("'", cohort_vars[i], "' specified in `cohort_vars` is not found in `data`."))
+      }
+  }
+
   }
   if (length(cohort_vars) != 1 & length(cohort_vars) != length(success_vars)) {
     stop('`cohort_vars` must be of length 1 or the same length as `success_vars` (each success variable corresponds to a cohort variable).')
@@ -113,7 +142,7 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
       ungroup
   } else {
     if (!(weight_var %in% names(data))) {
-      stop(paste0('The weight variable `', weight_var, '`', ' is not in `data`.'))
+      stop(paste0("The weight variable '", weight_var, "'", ' is not in `data`.'))
     }
     if (any(is.na(data[[weight_var]]))) {
       stop(paste0("The specified column corresponding to weight_var='", weight_var, "' contain NA values."))
@@ -134,13 +163,17 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
       lapply(function(x) c(unique(x), '- All')) %>%
       expand.grid(stringsAsFactors=FALSE)
 
-    # Exclude
+    # Exclude scenarios
     if (!is.null(exclude_scenario_df)) {
+      if (!all(names(exclude_scenario_df) %in% scenario_repeat_by_vars)) {
+        stop('`exclude_scenario_df` contain variables that are not specified in `scenario_repeat_by_vars`.')
+      }
       exclude__ <- NULL # CRAN: no visible binding for global variable
       dRepeatScenarios0 <- dRepeatScenarios0 %>%
         left_join(exclude_scenario_df %>% mutate(exclude__=1)) %>%
-        filter(!is.na(exclude__)) %>%
-        select(one_of(scenario_repeat_by_vars))
+        filter(is.na(exclude__)) %>% # missing means not meant to be excluded
+        # select(one_of(scenario_repeat_by_vars))
+        select(one_of(names(dRepeatScenarios0)))
     }
     
     # For each combination, determine row indices; take only combination with actual observations
@@ -234,7 +267,7 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
   ppg_check_valid_reference <- di_80_check_valid_reference <- di_80_index_reference_group <- NULL # CRAN: no visible binding for global variable
   dScenarios <- expand.grid(success_var=success_vars, group_var=group_vars, min_moe=min_moe, use_prop_in_moe=use_prop_in_moe, prop_sub_0=prop_sub_0, prop_sub_1=prop_sub_1, ppg_check_valid_reference=FALSE, di_prop_index_cutoff=di_prop_index_cutoff, di_80_index_cutoff=di_80_index_cutoff, di_80_check_valid_reference=FALSE, stringsAsFactors=FALSE) %>%
     left_join(lu_success_cohort, by=c('success_var')) %>% 
-    left_join(dRef, by=c('group_var')) %>%
+    left_join(dRef, by=c('group_var')) %>% 
     select(success_var, group_var, cohort_var, ppg_reference_group, min_moe, use_prop_in_moe, prop_sub_0, prop_sub_1, ppg_check_valid_reference, di_prop_index_cutoff, di_80_index_cutoff, di_80_index_reference_group, di_80_check_valid_reference)
 
   # Function to iterate for each scenario
